@@ -435,7 +435,9 @@ static int do_auth_external (int sock, const char *command, const char *name)
      */
     char buf[256];
 
-    if (!strstr(capabilities, "SASL-IR")) {
+    if (!strstr(capabilities, "SASL-IR") && !strstr(capabilities, "SASL_IR")) {
+	/* Cyrus IMAP 3.10 and newer advertise SASL_IR, which appears to be
+	 * a typo.  https://github.com/cyrusimap/cyrus-imapd/issues/5481 */
 	report(stderr, GT_("server did not advertise SASL-IR extension but fetchmail's implementation requires it for AUTHENTICATE EXTERNAL\n"));
 	return PS_AUTHFAIL;
     }
@@ -547,7 +549,7 @@ static int imap_getauth(int sock, struct query *ctl, char *greeting)
 	    } else {
 		set_timeout(0);
 		if (outlevel >= O_VERBOSE) {
-		    report(stdout, GT_("%s: opportunistic upgrade to TLS failed, trying to continue\n"), commonname);
+		    report(stdout, GT_("%s: opportunistic upgrade to TLS failed, trying to continue.\n"), commonname);
 		}
 		/* We don't know whether the connection is in a working state, so
 		 * test by issuing a NOOP. */
@@ -728,7 +730,7 @@ static int imap_getauth(int sock, struct query *ctl, char *greeting)
 	    pwl = 2 * strlen(ctl->password) + 1;
 	    if (remotename) xfree(remotename);
 	    remotename = (char *)xmalloc(rnl);
-	    if (password) xfree(password);
+	    if (password) xzerofree(password);
 	    password = (char *)xmalloc(pwl);
 
 	    imap_canonicalize(remotename, ctl->remotename, rnl);
@@ -736,10 +738,8 @@ static int imap_getauth(int sock, struct query *ctl, char *greeting)
 
 	    snprintf(shroud, sizeof (shroud), "\"%s\"", password);
 	    ok = gen_transact(sock, "LOGIN \"%s\" \"%s\"", remotename, password);
-	    memset(shroud, 0x55, sizeof(shroud));
-	    shroud[0] = '\0';
-	    memset(password, 0x55, strlen(password));
-	    xfree(password);
+	    fm_safe_clearmem(shroud, sizeof(shroud));
+	    xzerofree(password);
 	    xfree(remotename);
 	    return ok; /* this assumes that password is the last authentication method to try */
 	}
